=== modified file 'NEWS'
--- NEWS	2011-11-08 16:29:37 +0000
+++ NEWS	2011-03-25 11:38:43 +0000
@@ -39,27 +39,12 @@
       Improves performance on projects with long histories like emacs.
       (John Arbash Meinel)
 
+    - Fix escaping of filenames in revision views.
+      (William Grant, #740142)
+
     - Fix support for displaying foreign revision ids.
       (Jelmer Vernooij, #736026)
 
-    - Add hook 'controller' to BranchWSGIApp, allowing other bzr plugins
-      to provide custom branch-specific controllers. (Jelmer Vernooij, #585822)
-
-    - Add privacy notification code to loggerhead, allowing branches to be
-      marked as private and a notification ribbon to be displayed via
-      javascript on the view pages. (JC Sackett, #823471)
-
-
-1.18.1 [24Mar2011]
-------------------
-
-    - Fix escaping of filenames in revision views.
-      (William Grant, #740142)
-
-    - Add missing import to loggerhead.trace, allowing start-loggerhead
-      to run when a log.roll config option is set.
-      (Max Kanat-Alexander, #673999)
-
 
 1.18 [10Nov2010]
 ----------------

=== modified file 'info.py'
--- info.py	2011-11-23 08:33:12 +0000
+++ info.py	2011-03-19 08:35:57 +0000
@@ -3,12 +3,11 @@
 
 bzr_plugin_name = "loggerhead"
 
-bzr_plugin_version = (1, 18, 1)  # Keep in sync with loggerhead/__init__.py
+bzr_plugin_version = (1, 18, 0)
 
 bzr_compatible_versions = [
     (1, 17, 0), (1, 18, 0), (2, 0, 0), (2, 1, 0), (2, 2, 0), (2, 3, 0),
-    (2, 4, 0), (2, 5, 0),
-    ]
+    (2, 4, 0)]
 
 bzr_minimum_version = bzr_compatible_versions[0]
 

=== modified file 'loggerhead/__init__.py'
--- loggerhead/__init__.py	2011-11-23 08:33:12 +0000
+++ loggerhead/__init__.py	2010-11-11 03:30:43 +0000
@@ -22,7 +22,7 @@
 
 import pkg_resources
 
-__version__ = '1.18.1'  # Keep in sync with ../info.py.
+__version__ = '1.18'
 required_bzrlib = (1, 17)
 
 pkg_resources.get_distribution('Paste>=1.6')

=== modified file 'loggerhead/apps/branch.py'
--- loggerhead/apps/branch.py	2011-11-23 08:18:35 +0000
+++ loggerhead/apps/branch.py	2011-07-07 19:09:11 +0000
@@ -13,7 +13,7 @@
 # You should have received a copy of the GNU General Public License
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
-
+#
 """The WSGI application for serving a Bazaar branch."""
 
 import logging
@@ -22,7 +22,6 @@
 
 import bzrlib.branch
 import bzrlib.errors
-from bzrlib.hooks import Hooks
 import bzrlib.lru_cache
 
 from paste import request
@@ -50,13 +49,7 @@
 
     def __init__(self, branch, friendly_name=None, config={},
                  graph_cache=None, branch_link=None, is_root=False,
-                 served_url=_DEFAULT, use_cdn=False, private=False,
-                 export_tarballs=True):
-        """Create branch-publishing WSGI app.
-
-        :param export_tarballs: If true, allow downloading snapshots of revisions
-            as tarballs.
-        """
+                 served_url=_DEFAULT, use_cdn=False, export_tarballs=True):
         self.branch = branch
         self._config = config
         self.friendly_name = friendly_name
@@ -68,30 +61,26 @@
         self.is_root = is_root
         self.served_url = served_url
         self.use_cdn = use_cdn
-        self.private = private
         self.export_tarballs = export_tarballs
 
-    def public_private_css(self):
-        if self.private:
-            return "private"
-        else:
-            return "public"
-
     def get_history(self):
+        file_cache = None
         revinfo_disk_cache = None
         cache_path = self._config.get('cachepath', None)
         if cache_path is not None:
             # Only import the cache if we're going to use it.
             # This makes sqlite optional
             try:
-                from loggerhead.changecache import RevInfoDiskCache
+                from loggerhead.changecache import (
+                    FileChangeCache, RevInfoDiskCache)
             except ImportError:
                 self.log.debug("Couldn't load python-sqlite,"
                                " continuing without using a cache")
             else:
+                file_cache = FileChangeCache(cache_path)
                 revinfo_disk_cache = RevInfoDiskCache(cache_path)
         return History(
-            self.branch, self.graph_cache,
+            self.branch, self.graph_cache, file_cache=file_cache,
             revinfo_disk_cache=revinfo_disk_cache, cache_key=self.friendly_name)
 
     def url(self, *args, **kw):
@@ -171,10 +160,6 @@
                     self.served_url = self.url([])
                 except bzrlib.errors.InvalidURL:
                     self.served_url = None
-        for hook in self.hooks['controller']:
-            controller = hook(self, environ)
-            if controller is not None:
-                return controller
         path = request.path_info_pop(environ)
         if not path:
             raise httpexceptions.HTTPMovedPermanently(
@@ -185,9 +170,9 @@
             environ['loggerhead.as_json'] = True
             path = request.path_info_pop(environ)
         cls = self.controllers_dict.get(path)
-        if cls is not None:
-            return cls(self, self.get_history)
-        raise httpexceptions.HTTPNotFound()
+        if cls is None:
+            raise httpexceptions.HTTPNotFound()
+        return cls(self, self.get_history)
 
     def app(self, environ, start_response):
         self.branch.lock_read()
@@ -201,23 +186,3 @@
                 raise
         finally:
             self.branch.unlock()
-
-
-class BranchWSGIAppHooks(Hooks):
-    """A dictionary mapping hook name to a list of callables for WSGI app branch hooks.
-    """
-
-    def __init__(self):
-        """Create the default hooks.
-        """
-        Hooks.__init__(self, "bzrlib.plugins.loggerhead.apps.branch",
-            "BranchWSGIApp.hooks")
-        self.add_hook('controller',
-            "Invoked when looking for the controller to use for a "
-            "branch subpage. The api signature is (branch_app, environ)."
-            "If a hook can provide a controller, it should return one, "
-            "as a standard WSGI app. If it can't provide a controller, "
-            "it should return None", (1, 19))
-
-
-BranchWSGIApp.hooks = BranchWSGIAppHooks()

=== modified file 'loggerhead/changecache.py'
--- loggerhead/changecache.py	2011-08-17 11:04:00 +0000
+++ loggerhead/changecache.py	2009-05-02 14:01:05 +0000
@@ -99,6 +99,24 @@
             pass
 
 
+class FileChangeCache(object):
+
+    def __init__(self, cache_path):
+
+        if not os.path.exists(cache_path):
+            os.mkdir(cache_path)
+
+        self._changes_filename = os.path.join(cache_path, 'filechanges.sql')
+
+    def get_file_changes(self, entry):
+        cache = FakeShelf(self._changes_filename)
+        changes = cache.get(entry.revid)
+        if changes is None:
+            changes = self.history.get_file_changes_uncached(entry)
+            cache.add(entry.revid, changes)
+        return changes
+
+
 class RevInfoDiskCache(object):
     """Like `RevInfoMemoryCache` but backed in a sqlite DB."""
 

=== modified file 'loggerhead/controllers/annotate_ui.py'
--- loggerhead/controllers/annotate_ui.py	2011-08-09 14:06:49 +0000
+++ loggerhead/controllers/annotate_ui.py	2011-04-22 17:22:26 +0000
@@ -46,11 +46,7 @@
                     change = self._history.get_changes([line_revid])[0]
                     change_cache[line_revid] = change
 
-                try:
-                    message = change.comment.splitlines()[0]
-                except IndexError:
-                    # Comment not present for this revision
-                    message = ""
+                message = change.comment.splitlines()[0]
 
                 if last_lineno:
                     # The revspan is of lines between the last revision and this one.
@@ -62,10 +58,6 @@
                 last_lineno = lineno
                 last_line_revid = line_revid
 
-        # Zero-size file. Return empty revisions.
-        if last_lineno is None:
-            return revisions
-
         # We never set a revspan for the last revision during the loop above, so set it here.
         revisions[last_lineno].revspan = lineno - last_lineno + 1
 

=== modified file 'loggerhead/controllers/download_ui.py'
--- loggerhead/controllers/download_ui.py	2011-11-25 01:41:07 +0000
+++ loggerhead/controllers/download_ui.py	2011-07-07 19:15:35 +0000
@@ -79,29 +79,22 @@
     def __call__(self, environ, start_response):
         """Stream a tarball from a bazaar branch."""
         # Tried to re-use code from downloadui, not very successful
-        if not self._branch.export_tarballs:
-            raise httpexceptions.HTTPForbidden(
-                "Tarball downloads are not allowed")
-        archive_format = "tgz"
+        format = "tar"
         history = self._history
         self.args = self.get_args(environ)
         if len(self.args):
             revid = history.fix_revid(self.args[0])
-            version_part = '-r' + self.args[0]
         else:
             revid = self.get_revid()
-            version_part = ''
-        # XXX: Perhaps some better suggestion based on the URL or path?
-        #
-        # TODO: Perhaps set the tarball suggested mtime to the revision
-        # mtime.
-        root = self._branch.friendly_name or 'branch'
-        encoded_filename = self.encode_filename(
-            root + version_part + '.' + archive_format)
-        headers = [
-            ('Content-Type', 'application/octet-stream'),
-            ('Content-Disposition',
-                "attachment; filename*=utf-8''%s" % (encoded_filename,)),
-            ]
-        start_response('200 OK', headers)
-        return export_archive(history, root, revid, archive_format)
+        if self._branch.export_tarballs:
+            root = 'branch'
+            encoded_filename = self.encode_filename(root + '.' + format)
+            headers = [
+                ('Content-Type', 'application/octet-stream'),
+                ('Content-Disposition',
+                 "attachment; filename*=utf-8''%s" % (encoded_filename,)),
+                ]
+            start_response('200 OK', headers)
+            return export_archive(history, root, revid, format)
+        else:
+            raise httpexceptions.HTTPSeeOther('/')

=== modified file 'loggerhead/controllers/revision_ui.py'
--- loggerhead/controllers/revision_ui.py	2011-11-23 08:18:35 +0000
+++ loggerhead/controllers/revision_ui.py	2011-07-07 19:09:11 +0000
@@ -118,14 +118,10 @@
         link_data = {}
         path_to_id = {}
         if path:
-            items = [x for x in file_changes.text_changes if x.filename == path]
-            if len(items) > 0:
-                item = items[0]
-                diff_chunks = diff_chunks_for_file(
-                    self._history._branch.repository, item.file_id,
-                    item.old_revision, item.new_revision)
-            else:
-                diff_chunks = None
+            item = [x for x in file_changes.text_changes if x.filename == path][0]
+            diff_chunks = diff_chunks_for_file(
+                self._history._branch.repository, item.file_id,
+                item.old_revision, item.new_revision)
         else:
             diff_chunks = None
             for i, item in enumerate(file_changes.text_changes):

=== modified file 'loggerhead/exporter.py'
--- loggerhead/exporter.py	2011-11-24 07:46:41 +0000
+++ loggerhead/exporter.py	2011-06-28 15:55:36 +0000
@@ -16,16 +16,6 @@
 
 
 class ExporterFileObject(object):
-    """Shim that accumulates temporarily written out data.
-
-    There are python tarfile classes that want to write to a file like object.
-    We want to stream data.  But wsgi assumes it can pull data from the
-    handler, rather than having bytes pushed.
-
-    So this class holds the data temporarily, until it is pulled.  It 
-    should never buffer everything because as soon as a chunk is produced, 
-    wsgi will be given the chance to take it.
-    """
 
     def __init__(self):
         self._buffer = []
@@ -39,22 +29,18 @@
         finally:
             self._buffer = []
 
-    def close(self):
-        pass
-
-
-def export_archive(history, root, revid, archive_format):
+
+def export_archive(history, root, revid, format=".tar.gz"):
     """Export tree contents to an archive
 
     :param history: Instance of history to export
     :param root: Root location inside the archive.
     :param revid: Revision to export
-    :param archive_format: Format of the archive, eg 'tar.gz'.
+    :param format: Format of the archive
     """
     fileobj = ExporterFileObject()
     tree = history._branch.repository.revision_tree(revid)
-    for _ in get_export_generator(tree=tree, root=root, fileobj=fileobj,
-        format=archive_format):
+    for _ in get_export_generator(tree=tree, root=root, fileobj=fileobj, format=format):
         yield fileobj.get_buffer()
     # Might have additonal contents written
     yield fileobj.get_buffer()

=== modified file 'loggerhead/history.py'
--- loggerhead/history.py	2011-11-23 08:29:50 +0000
+++ loggerhead/history.py	2011-07-07 19:09:11 +0000
@@ -45,6 +45,7 @@
 from loggerhead import search
 from loggerhead import util
 from loggerhead.wholehistory import compute_whole_history_data
+from bzrlib.export.tar_exporter import export_tarball
 
 
 def is_branch(folder):
@@ -216,6 +217,8 @@
     around it, serve the request, throw the History object away, unlock the
     branch and throw it away.
 
+    :ivar _file_change_cache: An object that caches information about the
+        files that changed between two revisions.
     :ivar _rev_info: A list of information about revisions.  This is by far
         the most cryptic data structure in loggerhead.  At the top level, it
         is a list of 3-tuples [(merge-info, where-merged, parents)].
@@ -283,10 +286,15 @@
                 self._rev_indices[revid] = seq
                 self._revno_revid[revno_str] = revid
 
-    def __init__(self, branch, whole_history_data_cache,
+    def __init__(self, branch, whole_history_data_cache, file_cache=None,
                  revinfo_disk_cache=None, cache_key=None):
         assert branch.is_locked(), (
             "Can only construct a History object with a read-locked branch.")
+        if file_cache is not None:
+            self._file_change_cache = file_cache
+            file_cache.history = self
+        else:
+            self._file_change_cache = None
         self._branch = branch
         self._branch_tags = None
         self._inventory_cache = {}
@@ -753,13 +761,19 @@
             entry["foreign_revid"] = mapping.vcs.show_foreign_revid(foreign_revid)
         return util.Container(entry)
 
-    def get_file_changes(self, entry):
+    def get_file_changes_uncached(self, entry):
         if entry.parents:
             old_revid = entry.parents[0].revid
         else:
             old_revid = bzrlib.revision.NULL_REVISION
         return self.file_changes_for_revision_ids(old_revid, entry.revid)
 
+    def get_file_changes(self, entry):
+        if self._file_change_cache is None:
+            return self.get_file_changes_uncached(entry)
+        else:
+            return self._file_change_cache.get_file_changes(entry)
+
     def add_changes(self, entry):
         changes = self.get_file_changes(entry)
         entry.changes = changes

=== modified file 'loggerhead/static/css/global.css'
--- loggerhead/static/css/global.css	2011-11-23 17:21:39 +0000
+++ loggerhead/static/css/global.css	2011-04-22 17:22:49 +0000
@@ -343,68 +343,3 @@
 #footer {
     font-size: 77%;
     }
-
-    
-/* ====================
-   Global notifications
-*/
-/* Move the content down so the notification banner doesn't hide any content. */
-body.global-notification-visible {
-    padding-top: 40px;
-    }
-body.global-notification-visible .login-logout {
-    top: 45px;
-    }
-.notification-private {
-    background-image: url(/static/images/notification-private.png); /* sprite-ref: icon-sprites */
-    background-repeat: no-repeat;
-    }
-.global-notification {
-    position: fixed;
-    z-index: 10;
-    top: 0;
-    left: 0;
-    right: 0;
-    padding: 8px 20px;
-    /* Define colour for browsers that don't support transparency */
-    background-color: #8d1f1f;
-    /* Set transparent background for browsers that support it */
-    background-color: rgba(125,0,0,0.9);
-    color: #fff;
-    text-shadow: 0 -1px 0 #631616;
-    font-size: 14px;
-    line-height: 21px;
-    font-weight: bold;
-    -moz-box-shadow: 0 0 5px #333;
-    -webkit-box-shadow: 0 0 5px #333;
-    box-shadow: 0 0 5px #333;
-    }
-.global-notification .sprite.notification-private {
-    float: left;
-    display: inline-block;
-    height: 21px;
-    width: 20px;
-    margin-right: 10px;
-    padding: 0;
-    }
-.global-notification-close, .global-notification-close:active,
-.global-notification-close:visited {
-    color: #e47a7a;
-    }
-.global-notification-close {
-    display: block;
-    position: absolute;
-    top: 11px;
-    right: 20px;
-    font-size: 12px;
-    font-weight: normal;
-    line-height: 14px;
-    }
-.global-notification-close .sprite.notification-close {
-    float: right;
-    display: block;
-    height: 9px;
-    width: 8px;
-    margin: 3px 0 0 7px;
-    padding: 0;
-    }

=== removed file 'loggerhead/static/images/notification-private.png'
Binary files loggerhead/static/images/notification-private.png and loggerhead/static/images/notification-private.png differ
=== modified file 'loggerhead/static/javascript/custom.js'
--- loggerhead/static/javascript/custom.js	2011-10-26 16:06:54 +0000
+++ loggerhead/static/javascript/custom.js	2009-04-01 15:28:21 +0000
@@ -1,4 +1,4 @@
-Y = YUI().use("base", "node", "io-base", "anim");
+Y = YUI().use("node", "io-base", "anim");
 
 var global_timeout_id = null;
 var global_search_request = null;
@@ -280,89 +280,3 @@
   }
 };
 
-var notification_node = null;
-/*
- * Display privacy notifications
- *
- * This should be called after the page has loaded e.g. on 'domready'.
- */
-function setup_privacy_notification(config) {
-    if (notification_node !== null) {
-        return;
-    }
-    var notification_text = 'The information on this page is private';
-    var hidden = true;
-    var target_id = "loggerheadCont";
-    if (config !== undefined) {
-        if (config.notification_text !== undefined) {
-            notification_text = config.notification_text;
-        }
-        if (config.hidden !== undefined) {
-            hidden = config.hidden;
-        }
-        if (config.target_id !== undefined) {
-            target_id = config.target_id;
-        }
-    }
-    var id_selector = "#" + target_id;
-    var main = Y.get(id_selector);
-    notification_node = Y.Node.create('<div></div>')
-        .addClass('global-notification');
-    if (hidden) {
-        notification_node.addClass('hidden');
-    }
-    var notification_span = Y.Node.create('<span></span>')
-        .addClass('sprite')
-        .addClass('notification-private');
-    notification_node.set('innerHTML', notification_text);
-    main.appendChild(notification_node);
-    notification_node.appendChild(notification_span);
-};
-
-function display_privacy_notification() {
-    /* Set a temporary class on the body for the feature flag,
-     this is because we have no way to use feature flags in
-     css directly. This should be removed if the feature
-     is accepted. */
-    var body = Y.get('body');
-    body.addClass('feature-flag-bugs-private-notification-enabled');
-    // Set the visible flag so that the content moves down.
-    body.addClass('global-notification-visible');
-
-    setup_privacy_notification();
-    var global_notification = Y.get('.global-notification');
-    if (global_notification.hasClass('hidden')) {
-        global_notification.addClass('transparent');
-        global_notification.removeClass('hidden');
-
-        var fade_in = new Y.Anim({
-            node: global_notification,
-            to: {opacity: 1},
-            duration: 0.3
-        });
-        var body_space = new Y.Anim({
-            node: 'body',
-            to: {'paddingTop': '40px'},
-            duration: 0.2,
-            easing: Y.Easing.easeOut
-        });
-        var black_link_space = new Y.Anim({
-            node: '.black-link',
-            to: {'top': '45px'},
-            duration: 0.2,
-            easing: Y.Easing.easeOut
-        });
-
-        fade_in.run();
-        body_space.run();
-        black_link_space.run();
-    }
-};
-
-Y.on('domready', function() {
-    var body = Y.get('body');
-    if (body.hasClass('private')) {
-        setup_privacy_notification();
-        display_privacy_notification();
-    }
-});

=== modified file 'loggerhead/templates/branchinfo.pt'
--- loggerhead/templates/branchinfo.pt	2011-11-25 01:23:32 +0000
+++ loggerhead/templates/branchinfo.pt	2009-01-23 20:53:40 +0000
@@ -1,5 +1,4 @@
-<div id="branch-info"
-  tal:condition="python:branch.served_url">
+<div id="branch-info">
   To get this branch, use: <br/>
   <code>bzr branch
   <tal:served-url tal:replace="python:branch.served_url" /></code>

=== modified file 'loggerhead/templates/breadcrumbs.pt'
--- loggerhead/templates/breadcrumbs.pt	2012-01-08 21:43:42 +0000
+++ loggerhead/templates/breadcrumbs.pt	2008-09-30 02:04:14 +0000
@@ -10,7 +10,7 @@
 
 <!-- Branch breadcrumbs (for the path within the branch) -->
 <span metal:define-macro="branch" class="breadcrumb">
-    <tal:block repeat="crumb branch_breadcrumbs">/<a tal:attributes="href python:url([crumb['suffix'], change.revno, crumb['path']])" tal:content="crumb/dir_name" tal:condition="not:repeat/crumb/end" /><span tal:replace="crumb/dir_name" tal:condition="repeat/crumb/end" /></tal:block>
+    <tal:block repeat="crumb branch_breadcrumbs">/<a tal:attributes="href python:url([crumb['suffix'], change.revno], file_id=crumb['file_id'])" tal:content="crumb/dir_name" tal:condition="not:repeat/crumb/end" /><span tal:replace="crumb/dir_name" tal:condition="repeat/crumb/end" /></tal:block>
 </span>
 
 <!-- Directory breadcrumbs (for the path leading up to the branch) -->

=== modified file 'loggerhead/templates/macros.pt'
--- loggerhead/templates/macros.pt	2011-11-04 18:16:32 +0000
+++ loggerhead/templates/macros.pt	2011-03-03 10:58:57 +0000
@@ -43,7 +43,7 @@
     <metal:block metal:define-slot="header_extras" />
   </head>
 
- <body tal:attributes="class python:branch.public_private_css()">
+<body>
     <!-- Loggerhead Content Area -->
       
       <div metal:define-slot="backlink" />

=== modified file 'loggerhead/templates/revision.pt'
--- loggerhead/templates/revision.pt	2011-11-23 08:33:55 +0000
+++ loggerhead/templates/revision.pt	2011-07-07 19:09:11 +0000
@@ -73,7 +73,7 @@
           <li tal:condition="python:remember != change.revno">
             <a tal:attributes="href python:url(['/revision', change.revno], remember=change.revno, compare_revid=None);
                                title string:compare with another revision"
-               tal:content="string:compare with another revision"></a></li>
+               tal:content="string:Compare with another revision"></a></li>
           <li tal:condition="python:(remember is not None) and (compare_revid is None) and (change.revno != remember)" >
             <a tal:attributes="href python:url(['/revision', change.revno], compare_revid=history.get_revno(remember))">
               compare with revision <tal:b content="python:history.get_revno(remember)" />
@@ -86,7 +86,7 @@
                tal:attributes="href python:url(['/diff', change.revno, history.get_revno(compare_revid)], clear=1)">download diff</a>
            </li>
            <li tal:condition="python:can_export">
-            <a tal:attributes="href python:url(['/tarball', change.revno])">download tarball</a>
+            <a tal:attributes="href python:url(['/tarball', change.revno])">Download tarball</a>
            </li>
           <li id="last"><a tal:attributes="href python:url(['/changes', change.revno]);
                                            title string:view history from revision ${change/revno}"

=== removed file 'loggerhead/tests/fixtures.py'
--- loggerhead/tests/fixtures.py	2011-11-25 02:28:56 +0000
+++ loggerhead/tests/fixtures.py	1970-01-01 00:00:00 +0000
@@ -1,43 +0,0 @@
-# Copyright (C) 2007, 2008, 2009, 2011 Canonical Ltd.
-#
-# This program is free software; you can redistribute it and/or modify
-# it under the terms of the GNU General Public License as published by
-# the Free Software Foundation; either version 2 of the License, or
-# (at your option) any later version.
-#
-# This program is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU General Public License for more details.
-#
-# You should have received a copy of the GNU General Public License
-# along with this program; if not, write to the Free Software
-# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
-
-from __future__ import absolute_import
-
-from fixtures import Fixture
-
-
-class SampleBranch(Fixture):
-
-    def __init__(self, testcase):
-        # Must be a bzr TestCase to hook into branch creation, unfortunately.
-        self.testcase = testcase
-
-    def setUp(self):
-        Fixture.setUp(self)
-
-        self.tree = self.testcase.make_branch_and_tree('.')
-
-        self.filecontents = (
-            'some\nmultiline\ndata\n'
-            'with<htmlspecialchars\n')
-        filenames = ['myfilename', 'anotherfile<']
-        self.testcase.build_tree_contents(
-            (filename, self.filecontents) for filename in filenames)
-        for filename in filenames:
-            self.tree.add(filename, '%s-id' % filename)
-        self.fileid = self.tree.path2id('myfilename')
-        self.msg = 'a very exciting commit message <'
-        self.revid = self.tree.commit(message=self.msg)

=== modified file 'loggerhead/tests/test_controllers.py'
--- loggerhead/tests/test_controllers.py	2011-11-25 01:41:07 +0000
+++ loggerhead/tests/test_controllers.py	2011-07-10 22:51:56 +0000
@@ -1,45 +1,18 @@
-# Copyright (C) 2008-2011 Canonical Ltd.
-#
-# This program is free software; you can redistribute it and/or modify
-# it under the terms of the GNU General Public License as published by
-# the Free Software Foundation; either version 2 of the License, or
-# (at your option) any later version.
-#
-# This program is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU General Public License for more details.
-#
-# You should have received a copy of the GNU General Public License
-# along with this program; if not, write to the Free Software
-# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
-
 from cStringIO import StringIO
 import logging
 import tarfile
-import tempfile
 
-from paste.fixture import (
-    AppError,
-    )
 from paste.httpexceptions import HTTPServerError
 
-from testtools.matchers import (
-    Matcher,
-    Mismatch,
-    )
-
 from bzrlib import errors
 import simplejson
 
 from loggerhead.apps.branch import BranchWSGIApp
 from loggerhead.controllers.annotate_ui import AnnotateUI
 from loggerhead.controllers.inventory_ui import InventoryUI
-from loggerhead.tests.test_simple import (
-    BasicTests,
-    consume_app,
-    TestWithSimpleTree,
-    )
+from loggerhead.controllers.revision_ui import RevisionUI
+from loggerhead.tests.test_simple import BasicTests, consume_app
+from loggerhead import util
 
 
 class TestInventoryUI(BasicTests):
@@ -120,18 +93,6 @@
         rev_ui.parse_args(env)
         self.assertIsInstance(rev_ui.get_values('', {}, []), dict)
 
-    def test_add_template_values(self):
-        branch_app = self.make_branch_app_for_revision_ui(
-                [('file', 'content\n')], [('file', 'new content\n')])
-        env = {'SCRIPT_NAME': '/',
-               'PATH_INFO': '/revision/1/non-existent-file',
-               'QUERY_STRING':'start_revid=1' }
-        revision_ui = branch_app.lookup_app(env)
-        path = revision_ui.parse_args(env)
-        values = revision_ui.get_values(path, revision_ui.kwargs, {})
-        revision_ui.add_template_values(values)
-        self.assertIs(values['diff_chunks'], None)
-
     def test_get_values_smoke(self):
         branch_app = self.make_branch_app_for_revision_ui(
                 [('file', 'content\n'), ('other-file', 'other\n')],
@@ -163,16 +124,16 @@
         tree = self.make_branch_and_tree('.')
         self.build_tree_contents([('filename', '')])
         tree.add(['filename'], [file_id])
-        for rev_id, text, message in rev_ids_texts:
+        for rev_id, text in rev_ids_texts:
             self.build_tree_contents([('filename', text)])
-            tree.commit(rev_id=rev_id, message=message)
+            tree.commit(rev_id=rev_id, message='.')
         tree.branch.lock_read()
         self.addCleanup(tree.branch.unlock)
         branch_app = BranchWSGIApp(tree.branch, friendly_name='test_name')
         return AnnotateUI(branch_app, branch_app.get_history)
 
     def test_annotate_file(self):
-        history = [('rev1', 'old\nold\n', '.'), ('rev2', 'new\nold\n', '.')]
+        history = [('rev1', 'old\nold\n'), ('rev2', 'new\nold\n')]
         ann_ui = self.make_annotate_ui_for_file_history('file_id', history)
         # A lot of this state is set up by __call__, but we'll do it directly
         # here.
@@ -184,24 +145,6 @@
         self.assertEqual('2', annotated[1].change.revno)
         self.assertEqual('1', annotated[2].change.revno)
 
-    def test_annotate_empty_comment(self):
-        # Testing empty comment handling without breaking
-        history = [('rev1', 'old\nold\n', '.'), ('rev2', 'new\nold\n', '')]
-        ann_ui = self.make_annotate_ui_for_file_history('file_id', history)
-        ann_ui.args = ['rev2']
-        annotate_info = ann_ui.get_values('filename',
-            kwargs={'file_id': 'file_id'}, headers={})
-
-    def test_annotate_file_zero_sized(self):
-        # Test against a zero-sized file without breaking. No annotation must be present.
-        history = [('rev1', '' , '.')]
-        ann_ui = self.make_annotate_ui_for_file_history('file_id', history)
-        ann_ui.args = ['rev1']
-        annotate_info = ann_ui.get_values('filename',
-            kwargs={'file_id': 'file_id'}, headers={})
-        annotated = annotate_info['annotated']
-        self.assertEqual(0, len(annotated))
-
 
 class TestFileDiffUI(BasicTests):
 
@@ -268,102 +211,16 @@
         revlog_ui = branch_app.lookup_app(env)
         self.assertOkJsonResponse(revlog_ui, env)
 
-
-class TestControllerHooks(BasicTests):
-
-    def test_dummy_hook(self):
-        return
-        # A hook that returns None doesn't influence the searching for
-        # a controller.
-        env = {'SCRIPT_NAME': '', 'PATH_INFO': '/custom'}
-        myhook = lambda app, environ: None
-        branch = self.make_branch('.')
-        self.addCleanup(branch.lock_read().unlock)
-        app = self.make_branch_app(branch)
-        self.addCleanup(BranchWSGIApp.hooks.uninstall_named_hook, 'controller',
-            'captain hook')
-        BranchWSGIApp.hooks.install_named_hook('controller', myhook, "captain hook")
-        self.assertRaises(KeyError, app.lookup_app, env)
-
-    def test_working_hook(self):
-        # A hook can provide an app to use for a particular request.
-        env = {'SCRIPT_NAME': '', 'PATH_INFO': '/custom'}
-        myhook = lambda app, environ: "I am hooked"
-        branch = self.make_branch('.')
-        self.addCleanup(branch.lock_read().unlock)
-        app = self.make_branch_app(branch)
-        self.addCleanup(BranchWSGIApp.hooks.uninstall_named_hook, 'controller',
-            'captain hook')
-        BranchWSGIApp.hooks.install_named_hook('controller', myhook, "captain hook")
-        self.assertEquals("I am hooked", app.lookup_app(env))
-
-
-class IsTarfile(Matcher):
-
-    def __init__(self, compression):
-        self.compression = compression
-
-    def match(self, content_bytes):
-        f = tempfile.NamedTemporaryFile()
-        try:
-            f.write(content_bytes)
-            f.flush()
-            tarfile.open(f.name, mode='r|' + self.compression)
-        finally:
-            f.close()
-
-
-class MatchesTarballHeaders(Matcher):
-
-    def __init__(self, expect_filename):
-        self.expect_filename = expect_filename
-
-    def match(self, response):
-        # Maybe the c-t should be more specific, but this is probably good for
-        # making sure it gets saved without the client trying to decompress it
-        # or anything.
-        if (response.header('Content-Type') == 'application/octet-stream'
-            and response.header('Content-Disposition') ==
-            "attachment; filename*=utf-8''" + self.expect_filename):
-            pass
-        else:
-            return Mismatch("wrong response headers: %r"
-                % response.headers)
-
-
-class TestDownloadTarballUI(TestWithSimpleTree):
+class TestDownloadTarballUI(BasicTests):
 
     def setUp(self):
         super(TestDownloadTarballUI, self).setUp()
+        self.createBranch()
 
     def test_download_tarball(self):
-        # Tarball downloads are enabled by default.
-        app = self.setUpLoggerhead()
-        response = app.get('/tarball')
-        self.assertThat(
-            response.body,
-            IsTarfile('gz'))
-        self.assertThat(
-            response,
-            MatchesTarballHeaders('branch.tgz'))
-
-    def test_download_tarball_of_version(self):
-        app = self.setUpLoggerhead()
-        response = app.get('/tarball/1')
-        self.assertThat(
-            response.body,
-            IsTarfile('gz'))
-        self.assertThat(
-            response,
-            MatchesTarballHeaders('branch-r1.tgz'))
-
-    def test_download_tarball_forbidden(self):
-        app = self.setUpLoggerhead(export_tarballs=False)
-        e = self.assertRaises(
-            AppError, 
-            app.get,
-            '/tarball')
-        self.assertContainsRe(
-            str(e),
-            '(?s).*403 Forbidden'
-            '.*Tarball downloads are not allowed')
+        app = self.setUpLoggerhead()
+        res = app.get('/tarball')
+        f = open('tarball', 'w')
+        f.write(res)
+        f.close()
+        self.failIf(not tarfile.is_tarfile('tarball'))
\ No newline at end of file

=== modified file 'loggerhead/tests/test_simple.py'
--- loggerhead/tests/test_simple.py	2011-11-25 02:28:56 +0000
+++ loggerhead/tests/test_simple.py	2011-06-28 14:19:58 +0000
@@ -33,9 +33,6 @@
 from paste.fixture import TestApp
 from paste.httpexceptions import HTTPExceptionHandler, HTTPMovedPermanently
 
-from loggerhead.tests.fixtures import (
-    SampleBranch,
-    )
 
 
 class BasicTests(TestCaseWithTransport):
@@ -59,8 +56,8 @@
         self.assertEqual(None, start[2])
         simplejson.loads(content)
 
-    def make_branch_app(self, branch, **kw):
-        branch_app = BranchWSGIApp(branch, friendly_name='friendly-name', **kw)
+    def make_branch_app(self, branch):
+        branch_app = BranchWSGIApp(branch, friendly_name='friendly-name')
         branch_app._environ = {
             'wsgi.url_scheme':'',
             'SERVER_NAME':'',
@@ -74,20 +71,18 @@
 
     def setUp(self):
         BasicTests.setUp(self)
-        self.sample_branch_fixture = SampleBranch(self)
-
-        # XXX: This could be cleaned up more... -- mbp 2011-11-25
-        self.useFixture(self.sample_branch_fixture)
-        self.tree = self.sample_branch_fixture.tree
-        self.fileid = self.sample_branch_fixture.fileid
-        self.filecontents = self.sample_branch_fixture.filecontents
-        self.msg = self.sample_branch_fixture.msg
-
-    def test_public_private(self):
-        app = self.make_branch_app(self.tree.branch, private=True)
-        self.assertEqual(app.public_private_css(), 'private')
-        app = self.make_branch_app(self.tree.branch)
-        self.assertEqual(app.public_private_css(), 'public')
+        self.createBranch()
+
+        self.filecontents = ('some\nmultiline\ndata\n'
+                             'with<htmlspecialchars\n')
+        filenames = ['myfilename', 'anotherfile<']
+        self.build_tree_contents(
+            (filename, self.filecontents) for filename in filenames)
+        for filename in filenames:
+            self.tree.add(filename, '%s-id' % filename)
+        self.fileid = self.tree.path2id('myfilename')
+        self.msg = 'a very exciting commit message <'
+        self.revid = self.tree.commit(message=self.msg)
 
     def test_changes(self):
         app = self.setUpLoggerhead()
@@ -104,10 +99,7 @@
         res = app.get('/changes')
         self.failUnless("To get this branch, use:" in res)
         self.failUnless("lp:loggerhead" in res)
-
-    def test_no_empty_download_location(self):
-        """With no served_url, no instructions how to get it"""
-        app = self.setUpLoggerhead()
+        app = self.setUpLoggerhead(served_url=None)
         res = app.get('/changes')
         self.failIf("To get this branch, use:" in res)
 

=== modified file 'loggerhead/util.py'
--- loggerhead/util.py	2012-01-08 21:43:42 +0000
+++ loggerhead/util.py	2011-06-27 14:17:38 +0000
@@ -226,7 +226,7 @@
 def html_escape(s):
     """Transform dangerous (X)HTML characters into entities.
 
-    Like cgi.escape, except also escaping \" and '. This makes it safe to use
+    Like cgi.escape, except also escaping " and '. This makes it safe to use
     in both attribute and element content.
 
     If you want to safely fill a format string with escaped values, use
@@ -484,7 +484,7 @@
     for index, dir_name in enumerate(dir_parts):
         inner_breadcrumbs.append({
             'dir_name': dir_name,
-            'path': '/'.join(dir_parts[:index + 1]),
+            'file_id': inv.path2id('/'.join(dir_parts[:index + 1])),
             'suffix': '/' + view,
         })
     return inner_breadcrumbs

